@@ -30,17 +30,16 @@ namespace Catch {
     struct TestCaseInfo;
     class TestCaseHandle;
     struct IConfig;
+    class IStream;
 
     struct ReporterConfig {
-        explicit ReporterConfig( IConfig const* _fullConfig );
+        ReporterConfig( IConfig const* _fullConfig, IStream const* _stream );
 
-        ReporterConfig( IConfig const* _fullConfig, std::ostream& _stream );
-
-        std::ostream& stream() const;
+        IStream const* stream() const;
         IConfig const* fullConfig() const;
 
     private:
-        std::ostream* m_stream;
+        IStream const* m_stream;
         IConfig const* m_fullConfig;
     };
 
@@ -151,8 +150,19 @@ namespace Catch {
         bool shouldReportAllAssertions = false;
     };
 
-    //! The common base for all reporters and event listeners
-    struct IStreamingReporter {
+    /**
+     * The common base for all reporters and event listeners
+     *
+     * Implementing classes must also implement:
+     *
+     *     //! User-friendly description of the reporter/listener type
+     *     static std::string getDescription()
+     *
+     * Generally shouldn't be derived from by users of Catch2 directly,
+     * instead they should derive from one of the utility bases that
+     * derive from this class.
+     */
+    class IEventListener {
     protected:
         //! Derived classes can set up their preferences here
         ReporterPreferences m_preferences;
@@ -160,9 +170,9 @@ namespace Catch {
         IConfig const* m_config;
 
     public:
-        IStreamingReporter( IConfig const* config ): m_config( config ) {}
+        IEventListener( IConfig const* config ): m_config( config ) {}
 
-        virtual ~IStreamingReporter(); // = default;
+        virtual ~IEventListener(); // = default;
 
         // Implementing class must also provide the following static methods:
         // static std::string getDescription();
@@ -173,8 +183,8 @@ namespace Catch {
 
         //! Called when no test cases match provided test spec
         virtual void noMatchingTestCases( StringRef unmatchedSpec ) = 0;
-        //! Called for all invalid arguments from the cli
-        virtual void reportInvalidArguments( StringRef invalidArgument ) = 0;
+        //! Called for all invalid test specs from the cli
+        virtual void reportInvalidTestSpec( StringRef invalidArgument ) = 0;
 
         /**
          * Called once in a testing run before tests are started
@@ -232,7 +242,7 @@ namespace Catch {
         virtual void listTags(std::vector<TagInfo> const& tags) = 0;
 
     };
-    using IStreamingReporterPtr = Detail::unique_ptr<IStreamingReporter>;
+    using IStreamingReporterPtr = Detail::unique_ptr<IEventListener>;
 
 } // end namespace Catch
 
