@@ -1,20 +1,22 @@
-/*
- *  Distributed under the Boost Software License, Version 1.0. (See accompanying
- *  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
- */
 
+//              Copyright Catch2 Authors
+// Distributed under the Boost Software License, Version 1.0.
+//   (See accompanying file LICENSE_1_0.txt or copy at
+//        https://www.boost.org/LICENSE_1_0.txt)
+
+// SPDX-License-Identifier: BSL-1.0
+
+#include <catch2/catch_config.hpp>
 #include <catch2/catch_approx.hpp>
 #include <catch2/catch_test_macros.hpp>
 #include <catch2/matchers/catch_matchers_string.hpp>
 #include <catch2/internal/catch_test_spec_parser.hpp>
+#include <catch2/catch_user_config.hpp>
 #include <catch2/catch_test_case_info.hpp>
-#include <catch2/catch_config.hpp>
 #include <catch2/internal/catch_commandline.hpp>
 #include <catch2/generators/catch_generators.hpp>
+#include <catch2/internal/catch_compiler_capabilities.hpp>
 
-#ifdef __clang__
-#   pragma clang diagnostic ignored "-Wc++98-compat"
-#endif
 
 namespace {
     auto fakeTestCase(const char* name, const char* desc = "") { return Catch::makeTestCaseInfo("", { name, desc }, CATCH_INTERNAL_LINEINFO); }
@@ -345,10 +347,23 @@ TEST_CASE( "Process can be configured on command line", "[config][command-line]"
         CHECK(config.shouldDebugBreak == false);
         CHECK(config.abortAfter == -1);
         CHECK(config.noThrow == false);
-        CHECK(config.reporterName == "console");
+        CHECK( config.reporterSpecifications.empty() );
 
         Catch::Config cfg(config);
         CHECK_FALSE(cfg.hasTestFilters());
+
+        // The Config is responsible for mixing in the default reporter
+        auto expectedReporter =
+#if defined( CATCH_CONFIG_DEFAULT_REPORTER )
+            CATCH_CONFIG_DEFAULT_REPORTER
+#else
+            "console"
+#endif
+            ;
+
+        CHECK( cfg.getReportersAndOutputFiles().size() == 1 );
+        CHECK( cfg.getReportersAndOutputFiles()[0] ==
+               Catch::ConfigData::ReporterAndFile{ expectedReporter, {} } );
     }
 
     SECTION("test lists") {
@@ -384,29 +399,67 @@ TEST_CASE( "Process can be configured on command line", "[config][command-line]"
     }
 
     SECTION("reporter") {
+        using vec_ReporterAndFile = std::vector<Catch::ConfigData::ReporterAndFile>;
+        using namespace std::string_literals;
         SECTION("-r/console") {
-            CHECK(cli.parse({"test", "-r", "console"}));
+            auto result = cli.parse({"test", "-r", "console"});
+            CAPTURE(result.errorMessage());
+            CHECK(result);
 
-            REQUIRE(config.reporterName == "console");
+            REQUIRE(config.reporterSpecifications == vec_ReporterAndFile{ {"console", {}} });
         }
         SECTION("-r/xml") {
-            CHECK(cli.parse({"test", "-r", "xml"}));
+            auto result = cli.parse({"test", "-r", "xml"});
+            CAPTURE(result.errorMessage());
+            CHECK(result);
 
-            REQUIRE(config.reporterName == "xml");
+            REQUIRE(config.reporterSpecifications == vec_ReporterAndFile{ {"xml", {}} });
         }
         SECTION("--reporter/junit") {
-            CHECK(cli.parse({"test", "--reporter", "junit"}));
+            auto result = cli.parse({"test", "--reporter", "junit"});
+            CAPTURE(result.errorMessage());
+            CHECK(result);
 
-            REQUIRE(config.reporterName == "junit");
-        }
-        SECTION("Only one reporter is accepted") {
-            REQUIRE_FALSE(cli.parse({ "test", "-r", "xml", "-r", "junit" }));
+            REQUIRE(config.reporterSpecifications == vec_ReporterAndFile{ {"junit", {}} });
         }
         SECTION("must match one of the available ones") {
             auto result = cli.parse({"test", "--reporter", "unsupported"});
             CHECK(!result);
 
-            REQUIRE_THAT(result.errorMessage(), Contains("Unrecognized reporter"));
+            REQUIRE_THAT(result.errorMessage(), ContainsSubstring("Unrecognized reporter"));
+        }
+        SECTION("With output file") {
+            auto result = cli.parse({ "test", "-r", "console::out.txt" });
+            CAPTURE(result.errorMessage());
+            CHECK(result);
+            REQUIRE(config.reporterSpecifications == vec_ReporterAndFile{ {"console", "out.txt"s} });
+        }
+        SECTION("With Windows-like absolute path as output file") {
+            auto result = cli.parse({ "test", "-r", "console::C:\\Temp\\out.txt" });
+            CAPTURE(result.errorMessage());
+            CHECK(result);
+            REQUIRE(config.reporterSpecifications == vec_ReporterAndFile{ {"console", "C:\\Temp\\out.txt"s} });
+        }
+        SECTION("Output file cannot be empty") {
+            auto result = cli.parse({"test", "--reporter", "console::"});
+            CHECK(!result);
+
+            REQUIRE_THAT(result.errorMessage(), ContainsSubstring("empty filename"));
+        }
+        SECTION("Multiple reporters") {
+            SECTION("All with output files") {
+                CHECK(cli.parse({ "test", "-r", "xml::output.xml", "-r", "junit::output-junit.xml" }));
+                REQUIRE(config.reporterSpecifications == vec_ReporterAndFile{ {"xml", "output.xml"s}, {"junit", "output-junit.xml"s} });
+            }
+            SECTION("Mixed output files and default output") {
+                CHECK(cli.parse({ "test", "-r", "xml::output.xml", "-r", "console" }));
+                REQUIRE(config.reporterSpecifications == vec_ReporterAndFile{ {"xml", "output.xml"s}, {"console", {}} });
+            }
+            SECTION("cannot have multiple reporters with default output") {
+                auto result = cli.parse({ "test", "-r", "console", "-r", "xml::output.xml", "-r", "junit" });
+                CHECK(!result);
+                REQUIRE_THAT(result.errorMessage(), ContainsSubstring("Only one reporter may have unspecified output file."));
+            }
         }
     }
 
@@ -438,7 +491,7 @@ TEST_CASE( "Process can be configured on command line", "[config][command-line]"
         SECTION("-x must be numeric") {
             auto result = cli.parse({"test", "-x", "oops"});
             CHECK(!result);
-            REQUIRE_THAT(result.errorMessage(), Contains("convert") && Contains("oops"));
+            REQUIRE_THAT(result.errorMessage(), ContainsSubstring("convert") && ContainsSubstring("oops"));
         }
 
      SECTION("wait-for-keypress") {
@@ -460,7 +513,7 @@ TEST_CASE( "Process can be configured on command line", "[config][command-line]"
             CHECK(!result);
 
 #ifndef CATCH_CONFIG_DISABLE_MATCHERS
-            REQUIRE_THAT(result.errorMessage(), Contains("never") && Contains("both"));
+            REQUIRE_THAT(result.errorMessage(), ContainsSubstring("never") && ContainsSubstring("both"));
 #endif
         }
     }
@@ -483,12 +536,12 @@ TEST_CASE( "Process can be configured on command line", "[config][command-line]"
         SECTION("-o filename") {
             CHECK(cli.parse({"test", "-o", "filename.ext"}));
 
-            REQUIRE(config.outputFilename == "filename.ext");
+            REQUIRE(config.defaultOutputFilename == "filename.ext");
         }
         SECTION("--out") {
             CHECK(cli.parse({"test", "--out", "filename.ext"}));
 
-            REQUIRE(config.outputFilename == "filename.ext");
+            REQUIRE(config.defaultOutputFilename == "filename.ext");
         }
     }
 
@@ -505,36 +558,36 @@ TEST_CASE( "Process can be configured on command line", "[config][command-line]"
 
     SECTION( "use-colour") {
 
-        using Catch::UseColour;
+        using Catch::ColourMode;
 
         SECTION( "without option" ) {
             CHECK(cli.parse({"test"}));
 
-            REQUIRE( config.useColour == UseColour::Auto );
+            REQUIRE( config.colourMode == ColourMode::PlatformDefault );
         }
 
         SECTION( "auto" ) {
-            CHECK(cli.parse({"test", "--use-colour", "auto"}));
+            CHECK( cli.parse( { "test", "--colour-mode", "default" } ) );
 
-            REQUIRE( config.useColour == UseColour::Auto );
+            REQUIRE( config.colourMode == ColourMode::PlatformDefault );
         }
 
         SECTION( "yes" ) {
-            CHECK(cli.parse({"test", "--use-colour", "yes"}));
+            CHECK(cli.parse({"test", "--colour-mode", "ansi"}));
 
-            REQUIRE( config.useColour == UseColour::Yes );
+            REQUIRE( config.colourMode == ColourMode::ANSI );
         }
 
         SECTION( "no" ) {
-            CHECK(cli.parse({"test", "--use-colour", "no"}));
+            CHECK(cli.parse({"test", "--colour-mode", "none"}));
 
-            REQUIRE( config.useColour == UseColour::No );
+            REQUIRE( config.colourMode == ColourMode::None );
         }
 
         SECTION( "error" ) {
-            auto result = cli.parse({"test", "--use-colour", "wrong"});
+            auto result = cli.parse({"test", "--colour-mode", "wrong"});
             CHECK( !result );
-            CHECK_THAT( result.errorMessage(), Contains( "colour mode must be one of" ) );
+            CHECK_THAT( result.errorMessage(), ContainsSubstring( "colour mode must be one of" ) );
         }
     }
 
@@ -571,7 +624,107 @@ TEST_CASE( "Process can be configured on command line", "[config][command-line]"
     }
 }
 
+TEST_CASE("Parsing sharding-related cli flags", "[sharding]") {
+    using namespace Catch::Matchers;
+
+    Catch::ConfigData config;
+    auto cli = Catch::makeCommandLineParser(config);
+
+    SECTION("shard-count") {
+        CHECK(cli.parse({ "test", "--shard-count=8" }));
+
+        REQUIRE(config.shardCount == 8);
+    }
+
+    SECTION("Negative shard count reports error") {
+        auto result = cli.parse({ "test", "--shard-count=-1" });
+
+        CHECK_FALSE(result);
+        REQUIRE_THAT(result.errorMessage(), ContainsSubstring("Shard count must be a positive number"));
+    }
+
+    SECTION("Zero shard count reports error") {
+        auto result = cli.parse({ "test", "--shard-count=0" });
+
+        CHECK_FALSE(result);
+        REQUIRE_THAT(result.errorMessage(), ContainsSubstring("Shard count must be a positive number"));
+    }
+
+    SECTION("shard-index") {
+        CHECK(cli.parse({ "test", "--shard-index=2" }));
+
+        REQUIRE(config.shardIndex == 2);
+    }
+
+    SECTION("Negative shard index reports error") {
+        auto result = cli.parse({ "test", "--shard-index=-12" });
+
+        CHECK_FALSE(result);
+        REQUIRE_THAT(result.errorMessage(), ContainsSubstring("Shard index must be a non-negative number"));
+    }
+
+    SECTION("Shard index 0 is accepted") {
+        CHECK(cli.parse({ "test", "--shard-index=0" }));
+
+        REQUIRE(config.shardIndex == 0);
+    }
+
+}
+
+TEST_CASE( "Parsing warnings", "[cli][warnings]" ) {
+    using Catch::WarnAbout;
+
+    Catch::ConfigData config;
+    auto cli = Catch::makeCommandLineParser( config );
+
+    SECTION( "NoAssertions" ) {
+        REQUIRE(cli.parse( { "test", "-w", "NoAssertions" } ));
+        REQUIRE( config.warnings == WarnAbout::NoAssertions );
+    }
+    SECTION( "NoTests is no longer supported" ) {
+        REQUIRE_FALSE(cli.parse( { "test", "-w", "NoTests" } ));
+    }
+    SECTION( "Combining multiple warnings" ) {
+        REQUIRE( cli.parse( { "test",
+                              "--warn", "NoAssertions",
+                              "--warn", "UnmatchedTestSpec" } ) );
+
+        REQUIRE( config.warnings == ( WarnAbout::NoAssertions | WarnAbout::UnmatchedTestSpec ) );
+    }
+}
+
 TEST_CASE("Test with special, characters \"in name", "[cli][regression]") {
     // This test case succeeds if we can invoke it from the CLI
     SUCCEED();
 }
+
+TEST_CASE("Various suspicious reporter specs are rejected",
+          "[cli][reporter-spec][approvals]") {
+    Catch::ConfigData config;
+    auto cli = Catch::makeCommandLineParser( config );
+
+    auto spec = GENERATE( as<std::string>{},
+                          "",
+                          "::console",
+                          "console::",
+                          "console::some-file::",
+                          "::console::some-file::" );
+    CAPTURE( spec );
+
+    auto result = cli.parse( { "test", "--reporter", spec } );
+    REQUIRE_FALSE( result );
+}
+
+TEST_CASE("Win32 colour implementation is compile-time optional",
+          "[approvals][cli][colours]") {
+    Catch::ConfigData config;
+    auto cli = Catch::makeCommandLineParser( config );
+
+    auto result = cli.parse( { "test", "--colour-mode", "win32" } );
+
+#if defined( CATCH_CONFIG_COLOUR_WIN32 )
+    REQUIRE( result );
+#else
+    REQUIRE_FALSE( result );
+#endif
+}
