@@ -1,9 +1,13 @@
-/*
- *  Distributed under the Boost Software License, Version 1.0. (See accompanying
- *  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
- */
+
+//              Copyright Catch2 Authors
+// Distributed under the Boost Software License, Version 1.0.
+//   (See accompanying file LICENSE_1_0.txt or copy at
+//        https://www.boost.org/LICENSE_1_0.txt)
+
+// SPDX-License-Identifier: BSL-1.0
 
 #include <catch2/catch_test_macros.hpp>
+#include <catch2/catch_template_test_macros.hpp>
 #include <catch2/matchers/catch_matchers_exception.hpp>
 #include <catch2/matchers/catch_matchers_floating_point.hpp>
 #include <catch2/matchers/catch_matchers_predicate.hpp>
@@ -104,12 +108,12 @@ namespace {
 } // end unnamed namespace
 
 TEST_CASE( "String matchers", "[matchers]" ) {
-    REQUIRE_THAT( testStringForMatching(), Contains( "string" ) );
+    REQUIRE_THAT( testStringForMatching(), ContainsSubstring( "string" ) );
     REQUIRE_THAT( testStringForMatching(),
-                  Contains( "string", Catch::CaseSensitive::No ) );
-    CHECK_THAT( testStringForMatching(), Contains( "abc" ) );
+                  ContainsSubstring( "string", Catch::CaseSensitive::No ) );
+    CHECK_THAT( testStringForMatching(), ContainsSubstring( "abc" ) );
     CHECK_THAT( testStringForMatching(),
-                Contains( "aBC", Catch::CaseSensitive::No ) );
+                ContainsSubstring( "aBC", Catch::CaseSensitive::No ) );
 
     CHECK_THAT( testStringForMatching(), StartsWith( "this" ) );
     CHECK_THAT( testStringForMatching(),
@@ -121,8 +125,8 @@ TEST_CASE( "String matchers", "[matchers]" ) {
 
 TEST_CASE( "Contains string matcher", "[.][failing][matchers]" ) {
     CHECK_THAT( testStringForMatching(),
-                Contains( "not there", Catch::CaseSensitive::No ) );
-    CHECK_THAT( testStringForMatching(), Contains( "STRING" ) );
+                ContainsSubstring( "not there", Catch::CaseSensitive::No ) );
+    CHECK_THAT( testStringForMatching(), ContainsSubstring( "STRING" ) );
 }
 
 TEST_CASE( "StartsWith string matcher", "[.][failing][matchers]" ) {
@@ -184,42 +188,42 @@ TEST_CASE( "Regex string matcher", "[matchers][.failing]" ) {
 TEST_CASE( "Matchers can be (AllOf) composed with the && operator",
            "[matchers][operators][operator&&]" ) {
     CHECK_THAT( testStringForMatching(),
-                Contains( "string" ) && Contains( "abc" ) &&
-                    Contains( "substring" ) && Contains( "contains" ) );
+                ContainsSubstring( "string" ) && ContainsSubstring( "abc" ) &&
+                    ContainsSubstring( "substring" ) && ContainsSubstring( "contains" ) );
 }
 
 TEST_CASE( "Matchers can be (AnyOf) composed with the || operator",
            "[matchers][operators][operator||]" ) {
     CHECK_THAT( testStringForMatching(),
-                Contains( "string" ) || Contains( "different" ) ||
-                    Contains( "random" ) );
+                ContainsSubstring( "string" ) || ContainsSubstring( "different" ) ||
+                    ContainsSubstring( "random" ) );
     CHECK_THAT( testStringForMatching2(),
-                Contains( "string" ) || Contains( "different" ) ||
-                    Contains( "random" ) );
+                ContainsSubstring( "string" ) || ContainsSubstring( "different" ) ||
+                    ContainsSubstring( "random" ) );
 }
 
 TEST_CASE( "Matchers can be composed with both && and ||",
            "[matchers][operators][operator||][operator&&]" ) {
     CHECK_THAT( testStringForMatching(),
-                ( Contains( "string" ) || Contains( "different" ) ) &&
-                    Contains( "substring" ) );
+                ( ContainsSubstring( "string" ) || ContainsSubstring( "different" ) ) &&
+                    ContainsSubstring( "substring" ) );
 }
 
 TEST_CASE( "Matchers can be composed with both && and || - failing",
            "[matchers][operators][operator||][operator&&][.failing]" ) {
     CHECK_THAT( testStringForMatching(),
-                ( Contains( "string" ) || Contains( "different" ) ) &&
-                    Contains( "random" ) );
+                ( ContainsSubstring( "string" ) || ContainsSubstring( "different" ) ) &&
+                    ContainsSubstring( "random" ) );
 }
 
 TEST_CASE( "Matchers can be negated (Not) with the ! operator",
            "[matchers][operators][not]" ) {
-    CHECK_THAT( testStringForMatching(), !Contains( "different" ) );
+    CHECK_THAT( testStringForMatching(), !ContainsSubstring( "different" ) );
 }
 
 TEST_CASE( "Matchers can be negated (Not) with the ! operator - failing",
            "[matchers][operators][not][.failing]" ) {
-    CHECK_THAT( testStringForMatching(), !Contains( "substring" ) );
+    CHECK_THAT( testStringForMatching(), !ContainsSubstring( "substring" ) );
 }
 
 template <typename T> struct CustomAllocator : private std::allocator<T> {
@@ -465,6 +469,7 @@ TEST_CASE( "Floating point matchers: float", "[matchers][floating-point]" ) {
     }
     SECTION( "ULPs" ) {
         REQUIRE_THAT( 1.f, WithinULP( 1.f, 0 ) );
+        REQUIRE_THAT(-1.f, WithinULP( -1.f, 0 ) );
 
         REQUIRE_THAT( nextafter( 1.f, 2.f ), WithinULP( 1.f, 1 ) );
         REQUIRE_THAT( 0.f, WithinULP( nextafter( 0.f, 1.f ), 1 ) );
@@ -1081,3 +1086,17 @@ TEST_CASE( "Matchers can take references",
 #ifdef __clang__
 #    pragma clang diagnostic pop
 #endif
+
+TEMPLATE_TEST_CASE(
+    "#2152 - ULP checks between differently signed values were wrong",
+    "[matchers][floating-point][ulp]",
+    float,
+    double ) {
+    using Catch::Matchers::WithinULP;
+
+    static constexpr TestType smallest_non_zero =
+        std::numeric_limits<TestType>::denorm_min();
+
+    CHECK_THAT( smallest_non_zero, WithinULP( -smallest_non_zero, 2 ) );
+    CHECK_THAT( smallest_non_zero, !WithinULP( -smallest_non_zero, 1 ) );
+}
