@@ -28,47 +28,24 @@ filelocParser = re.compile(r'''
 ''', re.VERBOSE)
 lineNumberParser = re.compile(r' line="[0-9]*"')
 hexParser = re.compile(r'\b(0[xX][0-9a-fA-F]+)\b')
-durationsParser = re.compile(r' time="[0-9]*\.[0-9]*"')
-sonarqubeDurationParser = re.compile(r''' duration=["'][0-9]+["']''')
+# Note: junit must serialize time with 3 (or or less) decimal places
+#       before generalizing this parser, make sure that this is checked
+#       in other places too.
+junitDurationsParser = re.compile(r' time="[0-9]+\.[0-9]{3}"')
+durationParser = re.compile(r''' duration=['"][0-9]+['"]''')
 timestampsParser = re.compile(r'\d{4}-\d{2}-\d{2}T\d{2}\:\d{2}\:\d{2}Z')
-versionParser = re.compile(r'Catch v[0-9]+\.[0-9]+\.[0-9]+(-\w*\.[0-9]+)?')
+versionParser = re.compile(r'Catch2 v[0-9]+\.[0-9]+\.[0-9]+(-\w*\.[0-9]+)?')
 nullParser = re.compile(r'\b(__null|nullptr)\b')
 exeNameParser = re.compile(r'''
     \b
-    (CatchSelfTest|SelfTest)  # Expected executable name
+    SelfTest                  # Expected executable name
     (?:.exe)?                 # Executable name contains .exe on Windows.
     \b
 ''', re.VERBOSE)
 # This is a hack until something more reasonable is figured out
 specialCaseParser = re.compile(r'file\((\d+)\)')
 
-# errno macro expands into various names depending on platform, so we need to fix them up as well
-errnoParser = re.compile(r'''
-    \(\*__errno_location\s*\(\)\)
-    |
-    \(\*__error\(\)\)
-    |
-    \(\*_errno\(\)\)
-''', re.VERBOSE)
 sinceEpochParser = re.compile(r'\d+ .+ since epoch')
-infParser = re.compile(r'''
-    \(\(float\)\(1e\+300\ \*\ 1e\+300\)\) # MSVC INFINITY macro
-    |
-    \(__builtin_inff\(\)\)                # Linux (ubuntu) INFINITY macro
-    |
-    \(__builtin_inff\ \(\)\)              # Fedora INFINITY macro
-    |
-    __builtin_huge_valf\(\)               # OSX macro
-''', re.VERBOSE)
-nanParser = re.compile(r'''
-    \(\(float\)\(\(\(float\)\(1e\+300\ \*\ 1e\+300\)\)\ \*\ 0\.0F\)\) # MSVC NAN macro
-    |
-    \(\(float\)\(INFINITY\ \*\ 0\.0F\)\) # Yet another MSVC NAN macro
-    |
-    \(__builtin_nanf\ \(""\)\)           # Linux (ubuntu) NAN macro
-    |
-    __builtin_nanf\("0x<hex\ digits>"\)  # The weird content of the brackets is there because a different parser has already ran before this one
-''', re.VERBOSE)
 
 # The weird OR is there to always have at least empty string for group 1
 tapTestNumParser = re.compile(r'^((?:not ok)|(?:ok)|(?:warning)|(?:info)) (\d+) -')
@@ -95,9 +72,15 @@ def diffFiles(fileA, fileB):
 
 
 def normalizeFilepath(line):
-    if catchPath in line:
-        # make paths relative to Catch root
-        line = line.replace(catchPath + os.sep, '')
+    # Sometimes the path separators used by compiler and Python can differ,
+    # so we try to match the path with both forward and backward path
+    # separators, to make the paths relative to Catch2 repo root.
+    forwardSlashPath = catchPath.replace('\\', '/')
+    if forwardSlashPath in line:
+        line = line.replace(forwardSlashPath + '/', '')
+    backwardSlashPath = catchPath.replace('/', '\\')
+    if backwardSlashPath in line:
+        line = line.replace(backwardSlashPath + '\\', '')
 
     m = langFilenameParser.match(line)
     if m:
@@ -130,7 +113,7 @@ def filterLine(line, isCompact):
     # strip out the test order number in TAP to avoid massive diffs for every change
     line = tapTestNumParser.sub("\g<1> {test-number} -", line)
 
-    # strip Catch version number
+    # strip Catch2 version number
     line = versionParser.sub("<version>", line)
 
     # replace *null* with 0
@@ -143,30 +126,44 @@ def filterLine(line, isCompact):
     line = hexParser.sub("0x<hex digits>", line)
 
     # strip durations and timestamps
-    line = durationsParser.sub(' time="{duration}"', line)
-    line = sonarqubeDurationParser.sub(' duration="{duration}"', line)
+    line = junitDurationsParser.sub(' time="{duration}"', line)
+    line = durationParser.sub(' duration="{duration}"', line)
     line = timestampsParser.sub('{iso8601-timestamp}', line)
     line = specialCaseParser.sub('file:\g<1>', line)
-    line = errnoParser.sub('errno', line)
     line = sinceEpochParser.sub('{since-epoch-report}', line)
-    line = infParser.sub('INFINITY', line)
-    line = nanParser.sub('NAN', line)
     return line
 
 
-def approve(baseName, args):
-    global overallResult
+def get_rawResultsPath(baseName):
+    return os.path.join(rootPath, '_{0}.tmp'.format(baseName))
+
+
+def get_baselinesPath(baseName):
+    return os.path.join(rootPath, '{0}.approved.txt'.format(baseName))
+
+
+def get_filteredResultsPath(baseName):
+    return os.path.join(rootPath, '{0}.unapproved.txt'.format(baseName))
+
+
+def run_test(baseName, args):
     args[0:0] = [cmdPath]
     if not os.path.exists(cmdPath):
         raise Exception("Executable doesn't exist at " + cmdPath)
-    baselinesPath = os.path.join(rootPath, '{0}.approved.txt'.format(baseName))
-    rawResultsPath = os.path.join(rootPath, '_{0}.tmp'.format(baseName))
-    filteredResultsPath = os.path.join(rootPath, '{0}.unapproved.txt'.format(baseName))
 
+    print(args)
+    rawResultsPath = get_rawResultsPath(baseName)
     f = open(rawResultsPath, 'w')
     subprocess.call(args, stdout=f, stderr=f)
     f.close()
 
+
+def check_outputs(baseName):
+    global overallResult
+    rawResultsPath = get_rawResultsPath(baseName)
+    baselinesPath = get_baselinesPath(baseName)
+    filteredResultsPath = get_filteredResultsPath(baseName)
+
     rawFile = io.open(rawResultsPath, 'r', encoding='utf-8', errors='surrogateescape')
     filteredFile = io.open(filteredResultsPath, 'w', encoding='utf-8', errors='surrogateescape')
     for line in rawFile:
@@ -194,6 +191,11 @@ def approve(baseName, args):
             overallResult = 1
 
 
+def approve(baseName, args):
+    run_test(baseName, args)
+    check_outputs(baseName)
+
+
 print("Running approvals against executable:")
 print("  " + cmdPath)
 
@@ -212,6 +214,19 @@ for reporter in reporters:
     reporter_args = ['-r', reporter]
     approve(filename, common_args + reporter_args)
 
+## All reporters at the same time
+
+common_args = ["~[!nonportable]~[!benchmark]~[approvals] *", "-s", "-w", "NoAssertions", "--order", "lex", "--rng-seed", "1"]
+filenames = ['{}.sw.multi'.format(reporter) for reporter in reporters]
+reporter_args = []
+for reporter, filename in zip(reporters, filenames):
+    reporter_args += ['-r', '{}::{}'.format(reporter, get_rawResultsPath(filename))]
+
+run_test("default.sw.multi", common_args + reporter_args)
+check_outputs("default.sw.multi")
+for reporter, filename in zip(reporters, filenames):
+    check_outputs(filename)
+
 
 if overallResult != 0:
     print("If these differences are expected, run approve.py to approve new baselines.")
