@@ -2,24 +2,32 @@
 
 #include <pcap.h>
 #include <pybind11/pybind11.h>
+#include <pybind11/stl.h>
 #include <spdlog/fmt/fmt.h>
 #include <spdlog/fmt/ostr.h>
+#include <spdlog/sinks/stdout_color_sinks.h>
 #include <spdlog/spdlog.h>
 
+#include <caracal/experimental.hpp>
 #include <caracal/pretty.hpp>
 #include <caracal/probe.hpp>
 #include <caracal/prober.hpp>
 #include <caracal/prober_config.hpp>
 #include <caracal/protocols.hpp>
+#include <caracal/reply.hpp>
+#include <caracal/utilities.hpp>
 #include <memory>
 
-#include "conversions.hpp"
+#include "./conversions.hpp"
 
 namespace py = pybind11;
+namespace Experimental = caracal::Experimental;
 namespace Protocols = caracal::Protocols;
 namespace Statistics = caracal::Statistics;
+namespace Utilities = caracal::Utilities;
 
 using caracal::Probe;
+using caracal::Reply;
 using caracal::Prober::Config;
 using caracal::Prober::Iterator;
 using caracal::Prober::probe;
@@ -37,6 +45,11 @@ ProbingStatistics py_probe(const Config& config, pybind11::iterable it) {
   return probe(config, iterator);
 }
 
+void log_to_stderr() {
+  spdlog::set_default_logger(spdlog::stderr_color_st("dummy"));
+  spdlog::set_default_logger(spdlog::stderr_color_st(""));
+}
+
 void set_log_level(int level) {
   if (level >= 50) {
     spdlog::set_level(spdlog::level::critical);
@@ -63,11 +76,48 @@ Probe make_probe(const std::string& data, const uint16_t src_port,
   return probe;
 }
 
+class ProberWrapper {
+ public:
+  ProberWrapper(const std::string& interface, uint64_t probing_rate,
+                uint64_t buffer_size, uint16_t caracal_id, bool integrity_check)
+      : prober_{interface, probing_rate, buffer_size, caracal_id,
+                integrity_check} {};
+
+  std::vector<Reply> probe(const std::vector<Probe>& probes,
+                           uint64_t timeout_ms) {
+    std::function<void()> check_exception = [&]() {
+      if (PyErr_CheckSignals() != 0) {
+        throw py::error_already_set();
+      }
+    };
+    return prober_.probe(probes, timeout_ms, check_exception);
+  }
+
+ private:
+  Experimental::Prober prober_;
+};
+
+void check_exception() {
+  if (PyErr_CheckSignals() != 0) {
+    throw py::error_already_set();
+  }
+}
+
+std::string source_ipv4_for(const std::string& interface_name) {
+  return Utilities::source_ipv4_for(interface_name).to_string();
+}
+
+std::string source_ipv6_for(const std::string& interface_name) {
+  return Utilities::source_ipv6_for(interface_name).to_string();
+}
+
 PYBIND11_MODULE(_pycaracal, m) {
   m.doc() = "Python bindings to a small subset of caracal.";
 
   m.def("make_probe", &make_probe);
+  m.def("log_to_stderr", &log_to_stderr);
   m.def("set_log_level", &set_log_level);
+  m.def("check_exception", &check_exception);
 
   py::class_<Probe>(m, "Probe")
       .def_readonly("dst_addr", &Probe::dst_addr)
@@ -81,6 +131,28 @@ PYBIND11_MODULE(_pycaracal, m) {
       .def("__eq__", &Probe::operator==)
       .def("__str__", &fmt::to_string<Probe>);
 
+  py::class_<Reply>(m, "Reply")
+      .def_readonly("capture_timestamp", &Reply::capture_timestamp)
+      .def_readonly("reply_src_addr", &Reply::reply_src_addr)
+      .def_readonly("reply_dst_addr", &Reply::reply_dst_addr)
+      .def_readonly("reply_id", &Reply::reply_id)
+      .def_readonly("reply_size", &Reply::reply_size)
+      .def_readonly("reply_ttl", &Reply::reply_ttl)
+      .def_readonly("reply_protocol", &Reply::reply_protocol)
+      .def_readonly("reply_icmp_type", &Reply::reply_icmp_type)
+      .def_readonly("reply_icmp_code", &Reply::reply_icmp_code)
+      .def_readonly("reply_mpls_labels", &Reply::reply_mpls_labels)
+      .def_readonly("probe_dst_addr", &Reply::probe_dst_addr)
+      .def_readonly("probe_id", &Reply::probe_id)
+      .def_readonly("probe_size", &Reply::probe_size)
+      .def_readonly("probe_protocol", &Reply::probe_protocol)
+      .def_readonly("quoted_ttl", &Reply::quoted_ttl)
+      .def_readonly("probe_src_port", &Reply::probe_src_port)
+      .def_readonly("probe_dst_port", &Reply::probe_dst_port)
+      .def_readonly("probe_ttl", &Reply::probe_ttl)
+      .def_readonly("rtt", &Reply::rtt)
+      .def("__str__", &fmt::to_string<Reply>);
+
   // pycaracal.prober
   auto m_prober = m.def_submodule("prober");
   // NOTE: The order is important here since a string is also an iterable.
@@ -143,4 +215,16 @@ PYBIND11_MODULE(_pycaracal, m) {
       .def_readonly("dropped", &pcap_stat::ps_drop)
       .def_readonly("interface_dropped", &pcap_stat::ps_ifdrop)
       .def("__str__", fmt::to_string<pcap_stat>);
+
+  // pycaracal.utilities
+  auto m_utilities = m.def_submodule("utilities");
+  m_utilities.def("get_default_interface", &Config::get_default_interface);
+  m_utilities.def("source_ipv4_for", &source_ipv4_for);
+  m_utilities.def("source_ipv6_for", &source_ipv6_for);
+
+  // pycaracal.experimental
+  auto m_experimental = m.def_submodule("experimental");
+  py::class_<ProberWrapper>(m_experimental, "Prober")
+      .def(py::init<std::string, uint64_t, uint64_t, uint16_t, bool>())
+      .def("probe", &ProberWrapper::probe);
 }
