@@ -3,6 +3,8 @@
 #include <chrono>
 #include <thread>
 
+#include "environment.hpp"
+
 namespace Timestamp = caracal::Timestamp;
 
 using std::chrono::duration_cast;
@@ -15,10 +17,15 @@ TEST_CASE("Timestamp") {
   std::this_thread::sleep_for(milliseconds(250));
   auto diff = Timestamp::difference(
       Timestamp::cast<Timestamp::tenth_ms>(steady_clock::now()), enc);
-  // We allow some tolerance for systems where sleep_for is not precise (e.g.
-  // macOS).
-  REQUIRE(diff / 10 >= 245);
-  REQUIRE(diff / 10 <= 255);
+
+  if (is_github && is_macos) {
+    REQUIRE(diff / 10 >= 245);
+  } else {
+    // We allow some tolerance for systems where sleep_for is not precise
+    // (e.g. macOS).
+    REQUIRE(diff / 10 >= 245);
+    REQUIRE(diff / 10 <= 255);
+  }
 
   for (uint64_t i = 0; i < 65535; i++) {
     auto dec = Timestamp::decode(131069 + i, Timestamp::encode(131069));
